@@ -75,8 +75,33 @@ if ((grep(/^besteffort$/, @{$type_list})) and ($reservationField ne "None")){
 }
 ');
 
+-- A advance-reservation inner job requires an advance-reservation container
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (8, 'YES', E'# An advance-reservation inner job requires an advance-reservation container
+my %type_hash = map { my ($k,$v) = /^([^=]+)(?:=(.+))?$/; $k => $v } @$type_list;
+
+if (exists($type_hash{inner})) {
+    my $sth = $dbh->prepare("SELECT reservation
+                             FROM jobs
+                             WHERE
+                                 job_id = $type_hash{inner} AND
+                                 state IN(''Waiting'',''Hold'',''toLaunch'',''toAckReservation'',
+                                          ''Launching'',''Running'',''Suspended'',''Resuming'') 
+                            ");
+    $sth->execute();
+    my ($container_reservation) = $sth->fetchrow_array();
+
+    if (defined($container_reservation)) {
+        if ($container_reservation eq "None" and not $reservationField eq "None") {
+            die("[ADMISSION RULE] Error: an advance-reservation inner job requires the container to be an advance reservation as well.\\n");
+        }
+    } else {
+        die("[ADMISSION RULE] Error: inner job is requesting an invalid container id.\\n");
+    }
+}
+');
+
 -- Force deploy jobs to go on resources with the deploy property
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (8, 'YES', E'# Tie the deploy job type and resource property together
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (9, 'YES', E'# Tie the deploy job type and resource property together
 if (grep(/^deploy$/, @{$type_list})){
     if ($jobproperties ne ""){
         $jobproperties = "($jobproperties) AND deploy = ''YES''";
@@ -87,7 +112,7 @@ if (grep(/^deploy$/, @{$type_list})){
 ');
 
 -- Prevent deploy type jobs on non-entire nodes
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (9, 'YES', E'# Restrict allowed properties for deploy jobs to force requesting entire nodes
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (10, 'YES', E'# Restrict allowed properties for deploy jobs to force requesting entire nodes
 my @bad_resources = ("cpu","core", "thread","resource_id",);
 if (grep(/^deploy$/, @{$type_list})){
     foreach my $mold (@{$ref_resource_list}){
@@ -105,7 +130,7 @@ if (grep(/^deploy$/, @{$type_list})){
 ');
 
 -- Force desktop_computing jobs to go on nodes with the desktop_computing property
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (10, 'YES', E'# Tie desktop computing job type and resource property together
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (11, 'YES', E'# Tie desktop computing job type and resource property together
 if (grep(/^desktop_computing$/, @{$type_list})){
     print("[ADMISSION RULE] Added automatically desktop_computing resource constraints\\n");
     if ($jobproperties ne ""){
@@ -124,7 +149,7 @@ if (grep(/^desktop_computing$/, @{$type_list})){
 
 -- Limit the number of reservations that a user can do.
 -- (overrided on user basis using the file: ~oar/unlimited_reservation.users)
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (11, 'YES', E'# Limit the number of advance reservations per user
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (12, 'YES', E'# Limit the number of advance reservations per user
 if ($reservationField eq "toSchedule") {
     my $unlimited=0;
     if (open(FILE, "< $ENV{HOME}/unlimited_reservation.users")) {
@@ -155,7 +180,7 @@ if ($reservationField eq "toSchedule") {
 ');
 
 -- Example of how to perform actions given usernames stored in a file
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (12, 'NO', E'# Example of how to perform actions given usernames stored in a file
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (13, 'NO', E'# Example of how to perform actions given usernames stored in a file
 open(FILE, "/tmp/users.txt");
 while (($queue_name ne "admin") and ($_ = <FILE>)){
     if ($_ =~ m/^\\s*$user\\s*$/m){
@@ -167,7 +192,7 @@ close(FILE);
 ');
 
 -- Limit walltime for interactive jobs
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (13, 'YES', E'# Limit the walltime for interactive jobs
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (14, 'YES', E'# Limit the walltime for interactive jobs
 my $max_walltime = OAR::IO::sql_to_duration("12:00:00");
 if (($jobType eq "INTERACTIVE") and ($reservationField eq "None")){ 
     foreach my $mold (@{$ref_resource_list}){
@@ -180,7 +205,7 @@ if (($jobType eq "INTERACTIVE") and ($reservationField eq "None")){
 ');
 
 -- specify the default walltime if it is not specified
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (14, 'YES', E'# Set the default walltime is not specified
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (15, 'YES', E'# Set the default walltime is not specified
 my $default_wall = OAR::IO::sql_to_duration("2:00:00");
 foreach my $mold (@{$ref_resource_list}){
     if (!defined($mold->[1])){
@@ -191,7 +216,7 @@ foreach my $mold (@{$ref_resource_list}){
 ');
 
 -- Check if types given by the user are right
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (15, 'YES', E'# Check if job types are valid
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (16, 'YES', E'# Check if job types are valid
 my @types = (
     qr/^container(?:=\\w+)?$/,                 qr/^deploy(?:=standby)?$/,
     qr/^desktop_computing$/,                   qr/^besteffort$/,
@@ -216,7 +241,7 @@ foreach my $t ( @{$type_list} ) {
 ');
 
 -- If resource types are not specified, then we force them to default
-INSERT INTO admission_rules (priority, enabled, rule) VALUES (16, 'YES', E'# Set resource type to default if not specified
+INSERT INTO admission_rules (priority, enabled, rule) VALUES (17, 'YES', E'# Set resource type to default if not specified
 foreach my $mold (@{$ref_resource_list}){
     foreach my $r (@{$mold->[0]}){
         my $prop = $r->{property};
@@ -231,4 +256,3 @@ foreach my $mold (@{$ref_resource_list}){
 }
 print("[ADMISSION RULE] Modify resource description with type constraints\\n");
 ');
-
