@@ -4,7 +4,6 @@
 
 $LOAD_PATH << '.'
 
-USER=ENV['USER']
 require 'oarrestapi_lib'
 require 'shared_examples'
 
@@ -15,6 +14,7 @@ $rjobid=""
 describe OarApi do
   before :all do
     @api = OarApi.new(APIURI)
+    @post_api = OarApi.new(POST_APIURI)
   end
 
   #############################################################
@@ -30,8 +30,8 @@ describe OarApi do
 
     it "should submit some jobs to populate the database" do
       jhash = { 'resource' => "/nodes=1/core=1" , 'script' => "id" , 'array' => '15' }
-      @api.submit_job(jhash)
-      $jobid = @api.jobstatus['id']
+      @post_api.submit_job(jhash)
+      $jobid = @post_api.jobstatus['id']
       $jobid.should be_a(Integer)
       $jobid.should > 0
       # Now, we wait for the 15th job to be terminated
@@ -62,8 +62,8 @@ describe OarApi do
                 'property' => "network_address like 'node%'", 
                 'script' => "ls;pwd;whoami;sleep 60" , 
                 'array' => '10' }
-      @api.submit_job(jhash)
-      $jobid = @api.jobstatus['id']
+      @post_api.submit_job(jhash)
+      $jobid = @post_api.jobstatus['id']
       $jobid.should be_a(Integer)
       $jobid.should > 0
       # Now, we wait for the 4th job to be running
@@ -87,8 +87,8 @@ describe OarApi do
 
     it "should have a reservation job just submitted" do
       jhash = { 'resource' => "/nodes=1/core=1" , 'script' => "ls;pwd;whoami;sleep 60" , 'reservation' => '2037-01-01 01:00:00' }
-      @api.submit_job(jhash)
-      $rjobid = @api.jobstatus['id']
+      @post_api.submit_job(jhash)
+      $rjobid = @post_api.jobstatus['id']
       $rjobid.should be_a(Integer)
       $rjobid.should > 0
     end
@@ -221,7 +221,7 @@ describe OarApi do
         @api.get_link_href_from_array(links,"resources").should == "#{APIPATH}jobs/#{id}/resources"
       end
       it "should return jobs owned by the #{USER} user" do
-        @api.value['items'][0]['owner'].should == "#{USER}"
+        @api.value['items'][0][@api.owner_key].should == "#{USER}"
       end
     end
 
@@ -267,7 +267,7 @@ describe OarApi do
       end
       it_should_behave_like "Job"
       it "should be owned by the #{USER} user" do
-        @api.value['owner'].should == "#{USER}"
+        @api.value[@api.owner_key].should == "#{USER}"
       end
     end
     context "(with non-existent job)" do
@@ -310,7 +310,7 @@ describe OarApi do
       end
       it_should_behave_like "Job"
       it "should be owned by the #{USER} user" do
-        @api.value['owner'].should == "#{USER}"
+        @api.value[@api.owner_key].should == "#{USER}"
       end
       it "should have resources and nodes details" do
         @api.value['resources'].should be_an(Array)
@@ -330,6 +330,9 @@ describe OarApi do
         it "should have a status" do
           @api.value.should have_key('status')
         end
+        it "should have a valid status field (scheduled or reserved or assigned)" do
+          @api.value['status'].should match(/(scheduled|reserved|assigned)/)
+        end
       end
     end
     context "(with non-existent job)" do
@@ -393,6 +396,9 @@ describe OarApi do
         it "should have a status" do
           @api.value.should have_key('status')
         end
+        it "should have a valid status field (scheduled or reserved or assigned)" do
+          @api.value['status'].should match(/(scheduled|reserved|assigned)/)
+        end
       end
     end
   end
@@ -414,7 +420,7 @@ describe OarApi do
         @api.value['status'].should_not be_nil
       end
       it "should have a valid status field (reserved or assigned)" do
-        @api.value['status'].should match(/(reserved|assigned)/)
+        @api.value['status'].should match(/(scheduled|reserved|assigned)/)
       end
     end
   end
@@ -650,16 +656,16 @@ describe OarApi do
   describe "Job submission" do
     it "should return a self link" do
       jhash = { 'resource' => "/nodes=1/core=1" , 'script' => "ls;pwd;whoami;sleep 60"}
-      @api.submit_job(jhash)
-      $ljobid = @api.jobstatus['id']
-      @api.value= @api.jobstatus
+      @post_api.submit_job(jhash)
+      $ljobid = @post_api.jobstatus['id']
+      @api.value= @post_api.jobstatus
       @api.get_self_link_href.should == "#{APIPATH}jobs/#{$ljobid}"
     end
     it "should return a 400 error on bad reservation date" do
       jhash = { 'resource' => "/nodes=1/core=1" , 'script' => "ls;pwd;whoami;sleep 60",
                 'reservation' => '1973-06-03 18:00:00' }
       begin
-        @api.submit_job(jhash)
+        @post_api.submit_job(jhash)
       rescue => e
         #puts e.response.body
         e.should respond_to('http_code')
@@ -674,16 +680,16 @@ describe OarApi do
 
   describe "Cleaning queue" do
     it "should delete the test jobs" do
-      @api.del_array_job($jobid)
-      @api.deletestatus['status'].should == "Delete request registered"
+      @post_api.del_array_job($jobid)
+      @post_api.deletestatus['status'].should == "Delete request registered"
     end
     it "should delete the test reservation" do
-      @api.del_array_job($rjobid)
-      @api.deletestatus['status'].should == "Delete request registered"
+      @post_api.del_array_job($rjobid)
+      @post_api.deletestatus['status'].should == "Delete request registered"
     end
     it "should delete the test job" do
-      @api.del_array_job($ljobid)
-      @api.deletestatus['status'].should == "Delete request registered"
+      @post_api.del_array_job($ljobid)
+      @post_api.deletestatus['status'].should == "Delete request registered"
     end
   end
 
@@ -709,7 +715,7 @@ describe OarApi do
       end
       t.should < timeout
       begin
-        @api.value=@api.post(@api.api,"jobs/#{$jobid+1}/resubmissions/new",nil)
+        @api.value=@post_api.post(@post_api.api,"jobs/#{$jobid+1}/resubmissions/new",nil)
       rescue => e
         puts e.response.body
       end
@@ -721,8 +727,8 @@ describe OarApi do
       @api.get_link_href_by_rel('parent').should == "#{APIPATH}jobs/#{$jobid+1}"
     end
     it "should delete the test job (cleaning)" do
-      @api.del_job(@api.value['id'])
-      @api.deletestatus['status'].should == "Delete request registered"
+      @post_api.del_job(@api.value['id'])
+      @post_api.deletestatus['status'].should == "Delete request registered"
     end
   end
 
